#Copyright 2018 Tim Wentlau.
#Distributed under the MIT License. See LICENSE in root of project.

def get_gpio_driver():
    from . import gpio_driver
    return gpio_driver.GPIODriver()

def get_i2c_driver(address, bus):
    from . import i2c_driver
    return i2c_driver.I2CDeviceDriver(address, bus)

def get_one_wire_driver(address):
    from . import one_wire
    return one_wire.OneWireDeviceDriver(address)

def default_i2c_bus():
    return 0

def shutdown():
    import subprocess
    import sys
    subprocess.run(["sudo", "shutdown", "now"], stderr=sys.stderr)

def reboot():
    import subprocess
    import sys
    subprocess.run(["sudo", "shutdown", "-r", "now"], stderr=sys.stderr)

def get_camera_driver(source):
    raise NotImplementedError

def service_commands(commands, app_name, app_id, script_path):
    raise NotImplementedError

def get_user_inputs():
    raise NotImplementedError

def detect_devices():
    
    return {
        "Platform": [{
            "name": "upython",
            
        }]
    }


""" Setup module for kervi generating setup package used with pip """
from setuptools import setup
import distutils
try:
    from ukervi.platforms.upython.version import VERSION
except:
    VERSION = "0.0.0"

try:
    distutils.dir_util.remove_tree("dist")
except:
    pass

setup(
    name='ukervi',
    author='Tim Wentzlau',
    author_email='tim.wentzlau@gmail.com',
    url='https://kervi.org',
    packages=[
        'ukervi',
        'ukervi/application',
        #'kervi/messaging',
        #'kervi/module',
        #'kervi/plugin',
        #'kervi/plugin/authentication',
        #'kervi/plugin/authentication/plain',
        #'kervi/plugin/messaging',
        #'kervi/plugin/messaging/email',
        #'kervi/plugin/storage',
        #'kervi/plugin/storage/sqlite',
        #'kervi/plugin/storage/sqlite_temp',
        #'kervi/routing',
        #'kervi/storage',
        #'kervi/zmq_spine',
        #'kervi/utility',
        'ukervi/platforms/upython',
        #'kervi/vision',
    ],
    version=VERSION,
    description="""
    This is a upython version of the Kervi framework.
    """,
    keywords=['upython', 'micropython', 'robotic', 'automation'],
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Intended Audience :: Education",
        "Intended Audience :: Information Technology",
        "Intended Audience :: Manufacturing",
        "Intended Audience :: Science/Research",
        "Topic :: Scientific/Engineering",
        "Topic :: Scientific/Engineering :: Human Machine Interfaces",
        "Topic :: Software Development :: Documentation",
        "Topic :: System :: Monitoring",
        "Environment :: Console",
        "Programming Language :: Python :: 3.4"
    ],
    install_requires=[
        'kervi-core'
    ],
    extras_require={
        
    },
    include_package_data=True,
    package_data={
        
    }
)
